@@ -302,10 +302,11 @@ install_theme = function(
     theme = gsub('\\s*/\\s*', '/', theme)  # remove spaces, e.g., user / repo -> user/repo
     branch = sub('^@', '', gsub(r, '\\2', theme))
     theme = gsub(r, '\\1', theme)
+    # the hugo-academic theme has moved
+    if (theme == 'gcushen/hugo-academic') theme = 'wowchemy/starter-academic'
     if (branch == '') branch = default_branch(theme, hostname)
   }
-  # the hugo-academic theme has moved
-  if (theme == 'gcushen/hugo-academic') theme = 'wowchemy/starter-academic'
+
   dir_create('themes')
   is_theme = FALSE
   in_dir('themes', {
@@ -330,6 +331,11 @@ install_theme = function(
       # post-process go.mod so that users don't need to install Go (it sounds
       # unbelievable that a user needs to install Go just to use a Hugo theme)
       download_modules(file.path(expdir, 'go.mod'))
+      # delete figure shortcode that uses http resources on Windows:
+      # https://github.com/rstudio/blogdown/issues/546#issuecomment-788253660
+      if (is_windows()) xfun::gsub_dir(
+        '\\{\\{< figure src="https?://.+ >}}', '', dir = expdir, ext = 'md'
+      )
       file.copy(list.files(expdir, full.names = TRUE), '../', recursive = TRUE)
     } else warning(
       "The theme has provided an example site. You should read the theme's documentation ",
@@ -342,8 +348,8 @@ install_theme = function(
       unlink(file.path(thndir, c('tn.png', 'screenshot.png')))
       del_empty_dir(thndir)
     }
-    # delete the .Rprofile if exists, since it's unlikely to be useful
-    unlink(file.path(zipdir, '.Rprofile'))
+    # delete the .Rprofile and .github folder if they exist, since they are unlikely to be useful
+    unlink(file.path(zipdir, c('.Rprofile', '.github')), recursive = TRUE)
     # check the minimal version of Hugo required by the theme
     if (update_hugo && is_theme) {
       if (!is.null(minver <- read_toml(theme_cfg)[['min_version']])) {
@@ -378,15 +384,12 @@ install_theme = function(
       file.copy(list.files(theme, full.names = TRUE), '../', recursive = TRUE)
       unlink(theme, recursive = TRUE)
     }
-    # themes may use config/_default/config.toml, e.g. hugo-academic; we need to
-    # move this config to the root dir, because blogdown assumes the config file
-    # is under the root dir
-    if (file.exists(cfg <- file.path('..', 'config', '_default', 'config.toml'))) {
-      file.rename(cfg, '../config.toml')
-      unlink('../config.yaml')
-    }
-    # remove the themesDir setting; it is unlikely that you need it
-    in_dir('..', change_config('themesDir', NA))
+    in_dir('..', {
+      # move the possible config/_default/config.toml to the root dir
+      move_config()
+      # remove the themesDir setting; it is unlikely that you need it
+      change_config('themesDir', NA)
+    })
   })
   if (is_theme) if (update_config) {
     change_config('theme', sprintf('"%s"', theme))
@@ -446,6 +449,18 @@ download_modules = function(mod) {
   unlink(with_ext(mod, c('.mod', '.sum')))
 }
 
+# themes may use config/_default/config.toml, e.g. hugo-academic; we need to
+# move this config to the root dir, because blogdown assumes the config file
+# is under the root dir
+move_config = function() {
+  f1 = config_files()
+  f2 = file.path('config', '_default', f1)
+  if (!any(i <- file_exists(f2))) return()
+  file.rename(f2[i], f1[i])
+  # delete config.yaml if config.toml exists
+  if (length(f1) >= 2 && file_exists(f1[1])) unlink(f1[2])
+}
+
 #' @param path The path to the new file under the \file{content} directory.
 #' @param kind The content type to create, i.e., the Hugo archetype. If the
 #'   archetype is a page bundle archetype, it should end with a slash, e.g.,
@@ -458,6 +473,9 @@ download_modules = function(mod) {
 new_content = function(path, kind = '', open = interactive()) {
   if (missing(kind)) kind = default_kind(path)
   path2 = with_ext(path, '.md')
+  # for a new content file to be created with a bundle archetype, its path
+  # should not contain index.md but only the dir name, otherwise the archetype
+  # will not be used
   if (grepl('/$', kind)) {
     path2 = dirname(path2)
     kind  = sub('/$', '', kind)
@@ -469,6 +487,7 @@ new_content = function(path, kind = '', open = interactive()) {
   )
   if (length(i <- grep(r <- ' created$', file2)) == 1) {
     file2 = sub(r, '', file2[i])
+    if (!grepl('[.]md$', file2)) file2 = file.path(file2, 'index.md')
   } else {
     # should the above method fail to identify the newly created .md, search for
     # the new file with brute force
